@@ -7,6 +7,7 @@ from django.db.models.signals import pre_save, post_save
 from django.dispatch import receiver
 from djangoldp.models import Model
 from .permissions import CirclePermissions, CircleMemberPermissions
+from .views import CircleMembersViewset
 
 
 MODEL_MODIFICATION_USER_FIELD = 'modification_user'
@@ -32,6 +33,9 @@ class Circle(Model):
         auto_author = 'owner'
         nested_fields = ["team", 'members']
         permission_classes = [CirclePermissions]
+        anonymous_perms = []
+        authenticated_perms = []
+        owner_perms = []
         rdf_type = 'hd:circle'
 
     def __str__(self):
@@ -53,10 +57,11 @@ class CircleMember(Model):
         container_path = "circle-members/"
         permission_classes = [CircleMemberPermissions]
         anonymous_perms = []
-        authenticated_perms = []
-        owner_perms = []
+        authenticated_perms = ['view', 'add']
+        owner_perms = ['inherit']
         unique_together = ['user', 'circle']
-        rdf_type='hd:circlemember'
+        rdf_type = 'hd:circlemember'
+        view_set = CircleMembersViewset
 
     def save(self, *args, **kwargs):
         if self.user:
@@ -79,7 +84,8 @@ def fix_user_hubl_workaround_493(sender, instance, **kwargs):
             instance.user = user
             instance.save()
         except:
-            instance.delete()
+            if instance.pk is not None:
+                instance.delete()
 
 @receiver(pre_save, sender=Circle)
 def set_jabberid(sender, instance, **kwargs):
