@@ -10,6 +10,21 @@ def get_client_ip(request):
         ip = request.META.get('REMOTE_ADDR')
     return ip
 
+def _append_circle_object_permissions(perms, obj, user):
+    '''Auxiliary function analyses a circle object for member permissions'''
+    # permissions gained by being a circle-member, and admin
+    if obj.members.filter(user=user).exists():
+        perms = perms.union({'view', 'add'})
+
+        if obj.members.filter(user=user).get().is_admin:
+            perms = perms.union({'change', 'delete'})
+
+    # permissions gained by the circle being public
+    if obj.status == 'Public':
+        perms = perms.union({'view', 'add'})
+
+    return perms
+
 class CirclePermissions(LDPPermissions):
     def user_permissions(self, user, obj_or_model, obj=None):
         if not isinstance(obj_or_model, ModelBase):
@@ -21,16 +36,7 @@ class CirclePermissions(LDPPermissions):
         if not user.is_anonymous:
             # object-level permissions
             if obj:
-                # permissions gained by being a circle-member, and admin
-                if obj.members.filter(user=user).exists():
-                    perms.add('view')
-
-                    if obj.members.filter(user=user).get().is_admin:
-                        perms = perms.union({'add', 'change', 'delete'})
-
-                # permissions gained by the circle being public
-                if obj.status == 'Public':
-                    perms = perms.union({'view', 'add'})
+                perms = _append_circle_object_permissions(perms, obj, user)
 
             # model-level permissions
             else:
@@ -88,8 +94,12 @@ class CircleMemberPermissions(LDPPermissions):
                             perms = perms.union({'delete', 'change'})
 
             # model-level permissions
+            # NOTE: if the request is made on a nested field, this could be the parent container object and model
+            # in our case, circle or the user model
             else:
-                perms = perms.union({'view', 'add'})
+                if obj is not None:
+                    if hasattr(obj, 'members'):
+                        perms = _append_circle_object_permissions(perms, obj, user)
 
         return list(perms)
     
